<?php

namespace Drupal\blazy;

/**
 * Provides extra utilities to work with Media.
 */
class BlazyMedia {

  /**
   * Prepares the Blazy iframe as a structured array ready for ::renderer().
   *
   * @param array $element
   *   The renderable array being modified.
   *
   * @todo support other Media file entities like at D8: Media Facebook, etc.
   */
  public static function build(array &$element = []) {
    $attributes            = &$element['#attributes'];
    $settings              = &$element['#settings'];
    $settings['player']    = empty($settings['lightbox']) && $settings['media_switch'] != 'content';
    $settings['use_image'] = !empty($settings['media_switch']);
    $iframe_attributes     = [
      'data-src' => $settings['embed_url'],
      'src' => 'about:blank',
      'class' => ['b-lazy', 'media__element'],
      'allowfullscreen' => '',
    ];

    // Prevents broken iframe when aspect ratio is empty.
    if (empty($settings['ratio']) && $settings['width']) {
      $iframe_attributes['width'] = $settings['width'];
      $iframe_attributes['height'] = $settings['height'];
    }

    $player_attributes = [
      'class'         => 'media__icon media__icon--play',
      'data-url'      => $settings['embed_url'],
      'data-autoplay' => $settings['autoplay_url'],
    ];

    if ($settings['use_media'] && $settings['player']) {
      $iframe = [
        '#type' => 'html_tag',
        '#tag' => 'iframe',
        '#value' => '',
        '#attributes' => $iframe_attributes,
      ];

      if ($settings['media_switch']) {
        $icon = '<span class="media__icon media__icon--close"></span>';
        $iframe['#suffix'] = $icon . '<span' . drupal_attributes($player_attributes) . '></span>';
      }

      $element['#iframe'] = $iframe;
    }

    // Iframe is removed on lazyloaded, puts data at non-removable storage.
    $attributes['data-media'] = drupal_json_encode(['type' => $settings['type'], 'scheme' => $settings['scheme']]);
    if ($settings['player']) {
      $attributes['class'][] = 'media--player';
    }
  }

}
