<?php

namespace Drupal\blazy\Plugin\Field\FieldFormatter;

/**
 * Plugin implementation of the 'Blazy File' to get videos within images/files.
 */
class BlazyFileFormatter extends BlazyFormatterBlazy {

  use BlazyFormatterTrait;
  use BlazyVideoTrait;

  /**
   * {@inheritdoc}
   */
  public function getRequiredForms() {
    return ['fieldable' => TRUE] + parent::getRequiredForms();
  }

  /**
   * {@inheritdoc}
   */
  public function buildElement(array &$element, $entity, $delta = 0) {
    $settings = $element['settings'];

    // Extract image item from file, and assign it to $element['item'] so that
    // Blazy can display an image along with video, or just mixed.
    if ($settings['type'] == 'video') {
      if ($image = $this->getImageItem($entity)) {
        $element['item'] = $image['item'];
        $element['settings'] = array_merge($settings, $image['settings']);
      }

      $this->getMediaItem($element, $entity);
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function getCaption($item, $caption) {
    if (isset($item->type) && $field = field_get_items($this->targetType, $item, $caption)) {
      // Just display text values.
      $text = isset($field[0]['value']) ? $field[0]['value'] : '';
      $text = isset($field[0]['safe_value']) ? $field[0]['safe_value'] : $text;

      // For other complex fields, display as renderable array.
      if (empty($text)) {
        return field_view_value($this->targetType, $item, $caption, $field[0], $this->viewMode);
      }
      else {
        return ['#markup' => filter_xss_admin($text)];
      }
    }

    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getScopedFormElements() {
    $bundles = $this->fieldDefinition['bundles'];

    return [
      'captions'      => $this->admin()->getFieldOptions($this->fieldInstance, [], $this->targetType, $bundles),
      'multimedia'    => TRUE,
      'target_type'   => $this->targetType,
      'use_view_mode' => TRUE,
    ] + parent::getScopedFormElements();
  }

}
